# Welcome to **hpm** 👋

> hpm - an HEPIA project manager

![banner](https://i.imgur.com/GAMyEle.png)

# Merge Requests

> Make sure to follow [those emojis](https://gitmoji.dev/) to clarify your title !

